@@ -1,7 +1,6 @@
 #!/usr/bin/env python3
 #coding=utf8
-
-import sys, os, socket
+import sys, os, socket, re
 import time, threading
 import pexpect
 import ipaddress
@@ -253,7 +252,7 @@ class LinuxDevice(object):
         # some host prompt "########## PDT PORTER VSRX INSTANCES
         # ###########" before login, it will be mis-treated as login
         # success. In such cases, users should give the prompt explicitly.
-        prompt = ["(?i)are you sure you want to continue connecting",
+        prompt = ["(?i)Are you sure you want to continue connecting (yes/no/[fingerprint])?",
                 "(?i)(?:password)|(?:passphrase for key)",
                 "(?i)terminal type",
                 #"(?i)permission denied",
@@ -454,6 +453,7 @@ class LinuxDevice(object):
         output = self.psession.before[len1:len2].decode("utf-8").strip("\r\n")
         # It's a bug workaround for the issues/669:
         output = re.sub(r"\x1b\[\?2004l\r", "", output)
+        #print("cmd: %s, output: %s" %(cmd, output))
 
         if kwargs.get("redirect", False):
             # If redirect option is set then don't log to stdout
@@ -464,7 +464,9 @@ class LinuxDevice(object):
             redirect_file.close()
         else:
             self.log("%s" %(output),
-                    level = LOG_INFO,
+                    level = 
+                    (len(cmd.strip()) > 0 and cmd.strip()[-1] != "&") and
+                    LOG_INFO or LOG_VERBOSE,
                     leading = "  ",
                     #color = output_color,
                     color = "dark_gray",
@@ -555,7 +557,7 @@ class LinuxDevice(object):
 
         count = int(timeout * 10)
         ratio = float(total) / count
-        self.log("%s %d seconds" %(description, timeout))
+        print("%s %d seconds" %(description, timeout))
         # You can use this flag to run as a thread
         self.terminate_loop = False
         for i in range(1, count + 1):
